@@ -4,7 +4,8 @@ load(system.file("testdata","testData_bilateral.RData", package = "IndexNumR"))
 
 indexMethods <- c("laspeyres", "paasche", "fisher", "tornqvist", "satovartia",
                   "dutot", "carli", "jevons", "harmonic", "cswd", "walsh", "ces",
-                  "geomLaspeyres", "geomPaasche", "tpd", "gk")
+                  "geomLaspeyres", "geomPaasche", "tpd", "gk", "palgrave", "drobish",
+                  "stuvel", "marshalledgeworth", "lowe", "young")
 outputTypes <- c("pop", "chained", "fixedbase")
 
 indexEqual <- function(pOrq, indexMethod, outputType, result){
